==> beans_logging-2.0.1.tar.gz: beans_logging-2.0.1/tests/test_beans_logging.py <==
# -*- coding: utf-8 -*-

import pytest

from beans_logging import LoggerConfigPM, Logger, logger, LoggerLoader


@pytest.fixture
def logger_loader():
    _logger_loader = LoggerLoader()

    yield _logger_loader

    del _logger_loader


def test_init(logger_loader):
    logger.info("Testing initialization of 'LoggerLoader'...")

    assert isinstance(logger_loader, LoggerLoader)
    assert logger_loader.handlers_map == {"default": 0}
    assert logger_loader.configs_dir == LoggerLoader._CONFIGS_DIR
    assert logger_loader.config_filename == LoggerLoader._CONFIG_FILENAME
    assert isinstance(logger_loader.config, LoggerConfigPM)

    logger.success("Done: Initialization of 'LoggerLoader'.")


def test_load(logger_loader):
    logger.info("Testing 'load' method of 'LoggerLoader'...")

    logger_loader.update_config(config={"level": "TRACE"})
    _logger: Logger = logger_loader.load()

    assert isinstance(_logger, Logger)
    assert _logger == logger
    _logger.trace("Tracing...")
    _logger.debug("Debugging...")
    _logger.info("Logging info.")
    _logger.success("Success.")
    _logger.warning("Warning something.")
    _logger.error("Error occured.")
    _logger.critical("CRITICAL ERROR.")

    logger.success("Done: 'load' method.")


def test_methods():
    logger.info("Testing 'logger' methods...")

    logger.trace("Tracing...")
    logger.debug("Debugging...")
    logger.info("Logging info.")
    logger.success("Success.")
    logger.warning("Warning something.")
    logger.error("Error occured.")
    logger.critical("CRITICAL ERROR.")

    logger.success("Done: 'logger' methods.")

==> beans_logging-4.3.3.tar.gz: beans_logging-4.3.3/tests/test_beans_logging.py <==
# -*- coding: utf-8 -*-

import pytest

from beans_logging import Logger, LoggerConfigPM, LoggerLoader


@pytest.fixture
def logger_loader():
    _logger_loader = LoggerLoader()

    yield _logger_loader

    del _logger_loader


@pytest.fixture
def logger():
    from beans_logging import logger

    yield logger

    del logger


def test_init(logger: Logger, logger_loader: LoggerLoader):
    logger.info("Testing initialization of 'LoggerLoader'...")

    assert isinstance(logger_loader, LoggerLoader)
    assert logger_loader.handlers_map == {"default": 0}
    assert logger_loader.config_file_path == LoggerLoader._CONFIG_FILE_PATH
    assert isinstance(logger_loader.config, LoggerConfigPM)

    logger.success("Done: Initialization of 'LoggerLoader'.\n")


def test_load(logger: Logger, logger_loader: LoggerLoader):
    logger.info("Testing 'load' method of 'LoggerLoader'...")

    logger_loader.update_config(config={"level": "TRACE"})
    _logger: Logger = logger_loader.load()

    assert isinstance(_logger, Logger)
    assert _logger == logger
    _logger.trace("Tracing...")
    _logger.debug("Debugging...")
    _logger.info("Logging info.")
    _logger.success("Success.")
    _logger.warning("Warning something.")
    _logger.error("Error occured.")
    _logger.critical("CRITICAL ERROR.")

    logger.success("Done: 'load' method.\n")


def test_methods(logger: Logger):
    logger.info("Testing 'logger' methods...")

    logger.trace("Tracing...")
    logger.debug("Debugging...")
    logger.info("Logging info.")
    logger.success("Success.")
    logger.warning("Warning something.")
    logger.error("Error occured.")
    logger.critical("CRITICAL ERROR.")

    logger.success("Done: 'logger' methods.\n")
